import { BulkSiteInviteRequest as BulkSiteInviteRequest$1, BulkSiteInviteResponse as BulkSiteInviteResponse$1, ResendSiteInviteRequest as ResendSiteInviteRequest$1, SiteInviteResponse as SiteInviteResponse$1, RevokeSiteInviteRequest as RevokeSiteInviteRequest$1, RevokeSiteInviteResponse as RevokeSiteInviteResponse$1 } from './index.typings.js';
import '@wix/sdk-types';

interface SiteInvite {
    /**
     * Invite ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * Site ID the user is invited to as a collaborator.
     * @format GUID
     * @readonly
     */
    siteId?: string;
    /**
     * Email address where the invite was sent.
     * @format EMAIL
     */
    email?: string;
    /** Role IDs included in the invite. */
    policyIds?: string[];
    /**
     * Deprecated. Use `inviterAccountId`.
     * @readonly
     * @deprecated
     */
    inviterId?: string;
    /**
     * Invite Status.
     *
     * Supported values:
     * - **Pending:** The invite has been sent and is valid, waiting for the user's response.
     * - **Used:** The invite has been accepted.
     * - **Deleted:** The invite has been deleted or revoked.
     * - **Declined:** The user declined the invite.
     * - **Expired:** The invite has expired without being accepted.
     */
    status?: InviteStatusWithLiterals;
    /** Link to accept the invite. */
    acceptLink?: string;
    /**
     * Inviting account ID.
     * @format GUID
     * @readonly
     */
    inviterAccountId?: string;
    /**
     * Account ID that accepted the invite. Populated only once the invite is accepted.
     * @format GUID
     * @readonly
     */
    acceptedByAccountId?: string | null;
    /** Date the invite was created. */
    dateCreated?: Date | null;
    /**
     * User's Wix Bookings staff ID, if relevant.
     * @format GUID
     */
    staffId?: string | null;
    /** Invite expiration date */
    expirationDate?: Date | null;
    /**
     * Location ids included in the invite
     * @format GUID
     * @readonly
     * @maxSize 20
     */
    locationIds?: string[];
}
/** Invite status stating whether the invite was accepted, waiting to be accepted, deleted etc.. */
declare enum InviteStatus {
    Pending = "Pending",
    Used = "Used",
    Deleted = "Deleted",
    Declined = "Declined",
    Expired = "Expired"
}
/** @enumType */
type InviteStatusWithLiterals = InviteStatus | 'Pending' | 'Used' | 'Deleted' | 'Declined' | 'Expired';
interface LocationRestriction {
    /**
     * @format GUID
     * @maxSize 20
     */
    locationIds?: string[];
}
interface SiteInviteResponse {
    /** Invites that were sent. */
    invite?: SiteInvite;
}
interface BulkSiteInviteRequest {
    /** Role IDs, referred to as policy IDs, to assign to the contributors. */
    policyIds: string[];
    /**
     * Email addresses to which the invites should be sent.
     * @minSize 1
     * @maxSize 10
     */
    emails: string[];
    /** Details explaining the purpose of the invite. */
    invitePurpose?: string | null;
    /** Language of emails to send. Relevant only for recipients that don't currently have a Wix user ID. Default: Site owner's language. */
    defaultEmailLanguage?: string | null;
    /** Location restriction for the invite. */
    locationRestriction?: LocationRestriction;
}
interface BulkSiteInviteResponse {
    /** Invites that were sent successfully. */
    invites?: SiteInvite[];
    /** Invites that failed. */
    failedEmails?: string[];
}
interface ResendSiteInviteRequest {
    /** Invite ID. */
    inviteId: string;
    /** Language of emails to send. Relevant only for recipients that don't currently have a Wix user ID. Default: Site owner's language. */
    defaultEmailLanguage?: string | null;
}
interface RevokeSiteInviteRequest {
    /** Invite ID. */
    inviteId: string;
}
interface RevokeSiteInviteResponse {
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function bulkInvite(): __PublicMethodMetaInfo<'POST', {}, BulkSiteInviteRequest$1, BulkSiteInviteRequest, BulkSiteInviteResponse$1, BulkSiteInviteResponse>;
declare function resendInvite(): __PublicMethodMetaInfo<'POST', {
    inviteId: string;
}, ResendSiteInviteRequest$1, ResendSiteInviteRequest, SiteInviteResponse$1, SiteInviteResponse>;
declare function revokeInvite(): __PublicMethodMetaInfo<'POST', {
    inviteId: string;
}, RevokeSiteInviteRequest$1, RevokeSiteInviteRequest, RevokeSiteInviteResponse$1, RevokeSiteInviteResponse>;

export { type __PublicMethodMetaInfo, bulkInvite, resendInvite, revokeInvite };
