import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { BulkInviteOptions, BulkSiteInviteResponse, ResendInviteOptions, SiteInviteResponse } from './index.typings.mjs';
export { AcceptSiteInviteRequest, AcceptSiteInviteResponse, BulkSiteInviteRequest, ContributorLimitation, CursorPaging, GetContributorLimitRequest, GetContributorLimitResponse, GetSiteInviteRequest, GetSiteInviteResponse, GetSiteInvitesRequest, GetSiteInvitesResponse, InviteStatus, LocationRestriction, Paging, ParseSiteInviteTokenRequest, ParseSiteInviteTokenResponse, QuerySiteInvitesRequest, QuerySiteInvitesResponse, QueryV2, QueryV2PagingMethodOneOf, ResendSiteInviteRequest, RevokeSiteInviteRequest, RevokeSiteInviteResponse, SiteInvite, SiteInviteRequest, SortOrder, Sorting, UpdateSiteInviteRequest, UpdateSiteInviteResponse } from './index.typings.mjs';

declare function bulkInvite$1(httpClient: HttpClient): BulkInviteSignature;
interface BulkInviteSignature {
    /**
     * Creates and sends emails inviting potential site contributors to become contributors in the requesting site.
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - Role IDs, referred to as policy IDs, to assign to the contributors.
     * @param - Filter options. The `emails` field **must** be passed.
     */
    (policyIds: string[], options?: BulkInviteOptions | undefined): Promise<BulkSiteInviteResponse>;
}
declare function resendInvite$1(httpClient: HttpClient): ResendInviteSignature;
interface ResendInviteSignature {
    /**
     * Resends the email invitation to a potential site contributor.
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - Invite ID.
     * @param - Filter options.
     */
    (inviteId: string, options?: ResendInviteOptions | undefined): Promise<SiteInviteResponse>;
}
declare function revokeInvite$1(httpClient: HttpClient): RevokeInviteSignature;
interface RevokeInviteSignature {
    /**
     * Revokes a pending site contributor invite.
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - Invite ID.
     */
    (inviteId: string): Promise<void>;
}

declare const bulkInvite: MaybeContext<BuildRESTFunction<typeof bulkInvite$1> & typeof bulkInvite$1>;
declare const resendInvite: MaybeContext<BuildRESTFunction<typeof resendInvite$1> & typeof resendInvite$1>;
declare const revokeInvite: MaybeContext<BuildRESTFunction<typeof revokeInvite$1> & typeof revokeInvite$1>;

export { BulkInviteOptions, BulkSiteInviteResponse, ResendInviteOptions, SiteInviteResponse, bulkInvite, resendInvite, revokeInvite };
