// src/identity-invites-v1-site-invite-site-invites.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/identity-invites-v1-site-invite-site-invites.http.ts
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressInvitesApiSiteInvitesApiUrl(opts) {
  const domainToMappings = {
    "www._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/invites-web",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      },
      {
        srcPath: "/invites",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/invites/invites/site",
        destPath: "/invites/site"
      },
      {
        srcPath: "/invites/invites/account",
        destPath: "/invites/account"
      },
      {
        srcPath: "/invites",
        destPath: ""
      },
      {
        srcPath: "/invites/site-invite",
        destPath: "/site-invite"
      },
      {
        srcPath: "/invites/account-invite",
        destPath: "/account-invite"
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "platform.rise.ai": [
      {
        srcPath: "/invites/site",
        destPath: "/invites/site"
      },
      {
        srcPath: "/site-invite",
        destPath: "/site-invite"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_site-invites";
function bulkInvite(payload) {
  function __bulkInvite({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.invites.v1.site_invite",
      method: "POST",
      methodFqn: "com.wixpress.invites.api.SiteInvitesApi.BulkInvite",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInvitesApiSiteInvitesApiUrl({
        protoPath: "/site-invite/bulk",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "invites.dateCreated" },
            { path: "invites.expirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __bulkInvite;
}
function resendInvite(payload) {
  function __resendInvite({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.invites.v1.site_invite",
      method: "POST",
      methodFqn: "com.wixpress.invites.api.SiteInvitesApi.ResendInvite",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInvitesApiSiteInvitesApiUrl({
        protoPath: "/site-invite/{inviteId}/resend",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "invite.dateCreated" },
            { path: "invite.expirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __resendInvite;
}
function revokeInvite(payload) {
  function __revokeInvite({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.invites.v1.site_invite",
      method: "POST",
      methodFqn: "com.wixpress.invites.api.SiteInvitesApi.RevokeInvite",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInvitesApiSiteInvitesApiUrl({
        protoPath: "/site-invite/{inviteId}/revoke",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __revokeInvite;
}

// src/identity-invites-v1-site-invite-site-invites.universal.ts
var InviteStatus = /* @__PURE__ */ ((InviteStatus2) => {
  InviteStatus2["Pending"] = "Pending";
  InviteStatus2["Used"] = "Used";
  InviteStatus2["Deleted"] = "Deleted";
  InviteStatus2["Declined"] = "Declined";
  InviteStatus2["Expired"] = "Expired";
  return InviteStatus2;
})(InviteStatus || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
async function bulkInvite2(policyIds, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    policyIds,
    emails: options?.emails,
    invitePurpose: options?.invitePurpose,
    defaultEmailLanguage: options?.defaultEmailLanguage,
    locationRestriction: options?.locationRestriction
  });
  const reqOpts = bulkInvite(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          policyIds: "$[0]",
          emails: "$[1].emails",
          invitePurpose: "$[1].invitePurpose",
          defaultEmailLanguage: "$[1].defaultEmailLanguage",
          locationRestriction: "$[1].locationRestriction"
        },
        singleArgumentUnchanged: false
      },
      ["policyIds", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function resendInvite2(inviteId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    inviteId,
    defaultEmailLanguage: options?.defaultEmailLanguage
  });
  const reqOpts = resendInvite(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          inviteId: "$[0]",
          defaultEmailLanguage: "$[1].defaultEmailLanguage"
        },
        singleArgumentUnchanged: false
      },
      ["inviteId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function revokeInvite2(inviteId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({ inviteId });
  const reqOpts = revokeInvite(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { inviteId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["inviteId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  InviteStatus,
  SortOrder,
  bulkInvite2 as bulkInvite,
  resendInvite2 as resendInvite,
  revokeInvite2 as revokeInvite
};
//# sourceMappingURL=index.typings.mjs.map